@@ -167,16 +167,16 @@ void PXM_audit(PXM *pxm)
 PXM * PXM_make(int ww, int hh, int nc)                                           //  15.08
 {
    uint     cc;
+   double   dcc;
 
    if (ww < 5 || hh < 5) {                                                       //  impose reasonableness limits
-      zmessageACK(Mwin,"image too small: %d %d",ww,hh);
+      zmessageACK(Mwin,"image too small: %d x %d",ww,hh);
       return 0;
    }
 
-   cc = ww * hh;
-   if (ww > wwhh_limit || hh > wwhh_limit || cc > 178000000) {                   //  avoid image > 2 GB memory          15.03
-      zmessageACK(Mwin,"image too big: %d %d",ww,hh);
-      exit(12);
+   if (ww > wwhh_limit1 || hh > wwhh_limit1 || ww * hh > wwhh_limit2) {          //  avoid image dimensions too big     16.03
+      zmessageACK(Mwin,"image too big: %dx%d",ww,hh);
+      return 0;
    }
 
    PXM *pxm = (PXM *) zmalloc(sizeof(PXM));
@@ -185,7 +185,12 @@ PXM * PXM_make(int ww, int hh, int nc)
    pxm->hh = hh;
    pxm->nc = nc;                                                                 //  nc = 3/4 for no/alpha channel      15.08
 
-   cc = cc * nc * sizeof(float);                                                 //  float[nc] per pixel
+   dcc = 1.0 * ww * hh * nc * sizeof(float);                                     //  float[nc] per pixel
+   if (dcc > 4095.0 * MEGA) {                                                    //  avoid image > 4 GB                 16.03
+      zmessageACK(Mwin,"image too big: %dx%d",ww,hh);
+      return 0;
+   }
+   cc = ww * hh * nc * sizeof(float); 
    pxm->pixels = (float *) zmalloc(cc);
    return pxm;
 }
@@ -210,7 +215,9 @@ void PXM_free(PXM *&pxm)
 
 void PXM_addalpha(PXM *pxm)                                                      //  15.08
 {
-   int      ww, hh, nc1, nc2, cc, ii;
+   uint     cc;
+   double   dcc;
+   int      ww, hh, nc1, nc2, ii;
    float    *pixels1, *pixels2, *pix1, *pix2;
    
    ww = pxm->ww;
@@ -220,6 +227,11 @@ void PXM_addalpha(PXM *pxm)
    pixels1 = pxm->pixels;
 
    nc2 = nc1 + 1;
+   dcc = 1.0 * ww * hh * nc2 * sizeof(float);                                    //  float[nc] per pixel
+   if (dcc > 4095.0 * MEGA) {                                                    //  avoid image > 4 GB                 16.03
+      zmessageACK(Mwin,"image too big: %dx%d",ww,hh);
+      exit(12);
+   }
    cc = ww * hh * nc2 * sizeof(float);
    pixels2 = (float *) zmalloc(cc);
 
@@ -245,14 +257,18 @@ void PXM_addalpha(PXM *pxm)
 
 PXM * PXM_copy(PXM *pxm1)
 {
-   int      cc, nc;
+   uint     cc;
+   int      ww, hh, nc;
    PXM      *pxm2;
    
+   ww = pxm1->ww;
+   hh = pxm1->hh;
    nc = pxm1->nc;
-   cc = pxm1->ww * pxm1->hh * nc * sizeof(float);
+   cc = ww * hh * nc * sizeof(float);
 
-   pxm2 = PXM_make(pxm1->ww,pxm1->hh,nc);                                        //  15.08
+   pxm2 = PXM_make(ww,hh,nc);                                                    //  15.08
    memcpy(pxm2->pixels,pxm1->pixels,cc);
+
    return pxm2;
 }
 
@@ -335,7 +351,7 @@ PXM * PXM_rescale(PXM *pxm1, int ww, int hh)
    ppix1 = pxm1->pixels;
 
    pxm2 = PXM_make(ww,hh,nc);                                                    //  output PXM
-   if (! pxm2) return 0;
+   if (! pxm2) return 0;                                                         //  too big or no memory
    ww2 = ww;
    hh2 = hh;
    ppix2 = pxm2->pixels;
@@ -535,6 +551,7 @@ PXM * PXM_rotate(PXM *pxm1, float anglex)
    hh2 = ww1*fabsf(sinf(angle)) + hh1*fabsf(cosf(angle));
 
    pxm2 = PXM_make(ww2,hh2,nc);                                                  //  output PXM
+   if (! pxm2) return 0;
    ppix2 = pxm2->pixels;
 
    for (ii = 0; ii < NWT; ii++)                                                  //  start worker threads
@@ -672,6 +689,8 @@ PXM * PXM_rotate2(PXM *pxm1, int angle)
 
 PXB * PXB_make(int ww, int hh, int ac)                                           //  15.08
 {
+   uint     cc;
+
    zthreadcrash();
 
    PXB *pxb = (PXB *) zmalloc(sizeof(PXB));
@@ -686,7 +705,7 @@ PXB * PXB_make(int ww, int hh, int ac)
    pxb->hh = hh;
    pxb->rs = gdk_pixbuf_get_rowstride(pxb->pixbuf);
    pxb->nc = 3 + ac;                                                             //  nc = 3/4 for no/alpha channel      15.08
-   int cc = hh * pxb->rs;
+   cc = hh * pxb->rs;
    memset(pxb->pixels,0,cc);
    return pxb;
 }
@@ -744,7 +763,11 @@ void PXB_addalpha(PXB *pxb)
    
    pixbuf1 = pxb->pixbuf;                                                        //  old pixbuf
    pixbuf2 = gdk_pixbuf_new(GDKRGB,1,8,ww,hh);                                   //  new pixbuf with alpha channel
-   
+   if (! pixbuf2) {
+      zmessageACK(Mwin,"memory allocation failure");                             //  16.03
+      exit(12);
+   }
+
    pixels1 = gdk_pixbuf_get_pixels(pixbuf1);
    pixels2 = gdk_pixbuf_get_pixels(pixbuf2);
    rs1 = gdk_pixbuf_get_rowstride(pixbuf1);
@@ -804,7 +827,10 @@ PXB * PXB_rescale(PXB *pxb1, int ww2, int hh2)
 
    zthreadcrash();
    pixbuf = gdk_pixbuf_scale_simple(pxb1->pixbuf,ww2,hh2,GDK_INTERP_BILINEAR);
-   if (! pixbuf) zappcrash("memory allocation failure");
+   if (! pixbuf) {
+      zmessageACK(Mwin,"memory allocation failure");
+      exit(12);
+   }
    PXB *pxb2 = PXB_make(pixbuf);
    return pxb2;
 }
@@ -818,7 +844,10 @@ PXB * PXB_rotate(PXB *pxb1, float angle)
 
    zthreadcrash();
    pixbuf = gdk_pixbuf_rotate(pxb1->pixbuf,angle);
-   if (! pixbuf) zappcrash("memory allocation failure");
+   if (! pixbuf) {
+      zmessageACK(Mwin,"memory allocation failure");
+      exit(12);
+   }
    PXB *pxb2 = PXB_make(pixbuf);
    return pxb2;
 }
@@ -842,6 +871,10 @@ PXB * PXM_PXB_copy(PXM *pxm1)
    ac = nc - 3;
 
    pxb2 = PXB_make(ww,hh,ac);
+   if (! pxb2) {
+      zmessageACK(Mwin,"memory allocation failure");
+      exit(12);
+   }
 
    for (py = 0; py < hh; py++)
    {
@@ -1093,7 +1126,7 @@ copy_pixels:
 
 /********************************************************************************/
 
-//  fast fixbuf rescale, bilinear interpolation, threaded
+//  fast pixbuf rescale, bilinear interpolation, threaded
 //  works best when the rescale ratio is between 0.5 and 2.0
 //  about 4x faster than gdk_pixbuf_scale_simple() if 4 processor cores avail. 
 //  alpha channel is not copied - used only in slide show for now
@@ -1102,6 +1135,7 @@ namespace pixbuf_rescale_fast_names {
    int      ww1, hh1, ww2, hh2, rs1, rs2, nc1, nc2;
    uint8    *pixels1, *pixels2;
    int      busy[max_threads];
+   int      nwt;
 }
 
 PIXBUF * pixbuf_rescale_fast(PIXBUF *pixbuf1, int ww, int hh)                    //  15.02
@@ -1113,7 +1147,13 @@ PIXBUF * pixbuf_rescale_fast(PIXBUF *pixbuf1, int ww, int hh)
    PIXBUF      *pixbuf2;
    uint8       *pix2;
 
+   nwt = NWT - 1;                                                                //  threads to use                     16.07   
+
    pixbuf2 = gdk_pixbuf_new(GDKRGB,0,8,ww,hh);
+   if (! pixbuf2) {
+      zmessageACK(Mwin,"memory allocation failure");
+      exit(12);
+   }
 
    ww1 = gdk_pixbuf_get_width(pixbuf1);
    hh1 = gdk_pixbuf_get_height(pixbuf1);
@@ -1127,12 +1167,12 @@ PIXBUF * pixbuf_rescale_fast(PIXBUF *pixbuf1, int ww, int hh)
    nc2 = gdk_pixbuf_get_n_channels(pixbuf2);                                     //  15.08
    pixels2 = gdk_pixbuf_get_pixels(pixbuf2);
 
-   for (int ii = 0; ii < NWT; ii++) {                                            //  start working threads
+   for (int ii = 0; ii < nwt; ii++) {                                            //  start working threads
       busy[ii] = 1;
       start_detached_thread(pixbuf_rescale_fast_thread,&Nval[ii]);
    }
 
-   for (int ii = 0; ii < NWT; ii++)                                              //  wait for all done
+   for (int ii = 0; ii < nwt; ii++)                                              //  wait for all done
       while (busy[ii]) zsleep(0.001);
 
    for (int py2 = 0; py2 < hh2; py2++) {                                         //  set last column of pixels black
@@ -1159,7 +1199,7 @@ void * pixbuf_rescale_fast_thread(void *arg)
    fww = 1.0 * ww1 / ww2;
    fhh = 1.0 * hh1 / hh2;
 
-   for (py2 = index; py2 < hh2-1; py2 += NWT)                                    //  loop output pixel rows
+   for (py2 = index; py2 < hh2-1; py2 += nwt)                                    //  loop output pixel rows
    for (px2 = 0; px2 < ww2-1; px2++)                                             //  loop output pixel cols
    {
       fx1 = px2 * fww;                                                           //  real position in input image
