@@ -63,8 +63,6 @@ void build_widgets()
    G_SIGNAL(Mwin,"key-press-event",KBpress,0);                                   //  connect KB events to main window
    G_SIGNAL(Mwin,"key-release-event",KBrelease,0);
 
-   drag_drop_connect(Mwin,m_open_drag);                                          //  connect drag-drop to main window
-   
    //  get hardware and set default font for screen widgets
    
    get_hardware_info(Mwin);
@@ -136,6 +134,8 @@ void build_widgets()
    G_SIGNAL(Gdrawin,"button-release-event",navi::mouse_event,0);
    G_SIGNAL(Gdrawin,"motion-notify-event",navi::mouse_event,0);
    G_SIGNAL(Gdrawin,"draw",navi::gallery_paint,null);
+   drag_drop_source(Gdrawin,navi::gallery_dragfile);                             //  start file drag-drop               16.08
+   drag_drop_dest(Gdrawin,navi::gallery_dropfile);                               //  accept drag-drop file              16.08
 
    //  W view widgets - geomaps
 
@@ -182,7 +182,7 @@ void build_widgets()
 
    //  F view menu buttons
    cchar * favorites_tip = ZTX("Favorite Functions");
-   cchar * file_tip = ZTX("File: Open, RAW, Rename, Trash, Print");
+   cchar * file_tip = ZTX("File: Open, RAW, Rename, Delete, Print");
    cchar * save_tip = ZTX("Save modified image file to disk");
    cchar * prev_next_tip = ZTX("Open previous or next file (left/right mouse click)");
    cchar * metadata_tip = ZTX("Metadata: Captions, Tags, Ratings, Geotags, Search ... ");
@@ -215,12 +215,14 @@ void build_widgets()
    //  W view menu buttons
    cchar * load_geomap_tip = ZTX("Choose a map for image locations");
    cchar * mapsearch_tip = ZTX("Set image search radius for map click");
-   cchar * geotag_groups_tip = ZTX("Find all images for a location [date]");
    cchar * search_images_tip = ZTX("Find images meeting select criteria");
+   cchar * locations_tip = ZTX("Find all images for a location [date]");
+   cchar * timeline_tip = ZTX("Show image counts by month, select and report");
 
    //  M view menu buttons                                                       //  OSM                                16.05
-   //  geotag_groups_tip (duplicate of W view)
    //  search_images_tip (duplicate of W view)
+   //  locations_tip (duplicate of W view)
+   //  timeline_tip (duplicate of W view)
 
    //  file popup menu
    cchar * clone_tip = ZTX("Open another window");
@@ -228,12 +230,11 @@ void build_widgets()
    cchar * prevfiles_tip = ZTX("Open the previously seen file");
    cchar * recentfiles_tip = ZTX("Open a recently seen file");
    cchar * newfiles_tip = ZTX("Open a newly added file");
-   cchar * ufraw_tip = ZTX("Open and edit a camera RAW file");
    cchar * rawtherapee_tip = ZTX("Open and edit a camera RAW file");
    cchar * rename_tip = ZTX("Change the image file name");
+   cchar * copy_move_tip = ZTX("Copy or Move an image file to a new location");
    cchar * create_tip = ZTX("Create a blank image");
-   cchar * trash_tip = ZTX("Move image file to Trash");
-   cchar * delete_tip = ZTX("Permanently delete image file");
+   cchar * deltrash_tip = ZTX("Delete or trash image file");
    cchar * print_tip = ZTX("Print the current image");
    cchar * print_calibrated_tip = ZTX("Print current image with adjusted colors");
    cchar * quit_tip = ZTX("Quit Fotoxx");
@@ -242,20 +243,22 @@ void build_widgets()
    cchar * meta_view_short_tip = ZTX("List a few key metadata items");
    cchar * meta_view_long_tip = ZTX("List all metadata items");
    cchar * captions_tip = ZTX("(Toggle) show captions and comments");
-   cchar * edit_metadata_tip = ZTX("Edit image tags/caption/rating ...");
+   cchar * edit_metadata_tip = ZTX("Edit image tags/geotags/caption/rating ...");
    cchar * meta_edit_any_tip = ZTX("Edit any image metadata");
-   cchar * meta_delete_tip = ZTX("Remove all metadata from an image");
+   cchar * meta_delete_tip = ZTX("Remove selected image metadata");
    cchar * batch_tags_tip = ZTX("Add/remove tags for multiple images");
    cchar * batch_rename_tags_tip = ZTX("Convert tag names for all images");
    cchar * batch_change_metadata_tip = ZTX("Add/change/delete metadata for multiple images");
    cchar * batch_report_metadata_tip = ZTX("Report metadata for multiple images");
-   cchar * edit_geotags_tip = ZTX("Edit image location and geotags");
    cchar * batch_geotags_tip = ZTX("Add/revise geotags for multiple images");
-   //  geotag_groups_tip
-   //  search_images_tip
+   //  search_images_tip (duplicate of W view)
+   //  locations_tip (duplicate of W view)
+   //  timeline_tip (duplicate of W view)
 
    //  select area popup menu
    cchar * select_tip = ZTX("Select object or area for editing");
+   cchar * select_find_gap_tip = ZTX("Find a gap in an area outline");
+   cchar * select_hairy_tip = ZTX("Select hairy or irregular edge");
    cchar * select_show_tip = ZTX("Show (outline) existing area");
    cchar * select_hide_tip = ZTX("Hide existing area");
    cchar * select_enable_tip = ZTX("Enable area for editing");
@@ -263,9 +266,9 @@ void build_widgets()
    cchar * select_invert_tip = ZTX("Reverse existing area");
    cchar * select_unselect_tip = ZTX("Erase existing area");
    cchar * select_copy_tip = ZTX("Copy area for later pasting into image");
-   cchar * select_paste_tip = ZTX("Paste previously copied area into image");
-   cchar * select_open_tip = ZTX("Open a file and paste as area into image");
    cchar * select_save_tip = ZTX("Save area to a file with transparency");
+   cchar * select_open_tip = ZTX("Open a file and paste as area into image");
+   cchar * select_paste_tip = ZTX("Paste previously copied area into image");
 
    //  edit popup menu
    cchar * trimrotate_tip = ZTX("Trim/Crop margins and/or Rotate");
@@ -274,13 +277,13 @@ void build_widgets()
    cchar * voodoo2_tip = ZTX("Fast auto enhance that may work OK");
    cchar * combo_tip = ZTX("Adjust brightness, contrast, color");
    cchar * tonemap_tip = ZTX("Add local contrast, enhance details");
-   cchar * britedist_tip = ZTX("Adjust brightness distribution");
+   cchar * britedist_tip = ZTX("Edit brightness distribution");
    cchar * zonal_flatten_tip = ZTX("Flatten zonal brightness distribution");
    cchar * resize_tip = ZTX("Change pixel dimensions");
    cchar * flip_tip = ZTX("Mirror image horizontally or vertically");
    cchar * write_text_tip = ZTX("Write text on image");
    cchar * write_line_tip = ZTX("Write lines or arrows on image");
-   cchar * brightramp_tip = ZTX("Fix brightness uniformity across image");
+   cchar * ramp_brightness_tip = ZTX("Fix brightness uniformity across image");
    cchar * paint_edits_tip = ZTX("Paint edit function gradually with mouse");
    cchar * lever_edits_tip = ZTX("Leverage edits by brightness or color");
    cchar * plugins_tip = ZTX("Edit plugins menu or run a plugin function");
@@ -299,7 +302,7 @@ void build_widgets()
    cchar * color_sat_tip = ZTX("Adjust color intensity (saturation)");
    cchar * adjust_RGB_tip = ZTX("Adjust color using RGB or CMY colors");
    cchar * adjust_HSL_tip = ZTX("Adjust color using HSL colors");
-   cchar * color_ramp_tip = ZTX("Adjust color in selected image areas");
+   cchar * ramp_color_tip = ZTX("Adjust color in selected image areas");
    cchar * match_color_tip = ZTX("Match colors on one image with another");
    cchar * color_profile_tip = ZTX("Convert to another color profile");
    cchar * remove_dust_tip = ZTX("Remove dust spots from scanned slides");
@@ -370,7 +373,7 @@ void build_widgets()
    cchar * batch_convert_tip = ZTX("Rename/convert/resize/move multiple files");
    cchar * batch_upright_tip = ZTX("Upright multiple rotated image files");
    cchar * batch_deltrash_tip = ZTX("Delete or Trash multiple files");
-   cchar * batch_dcraw_tip = ZTX("Convert camera RAW files using DCraw");
+   cchar * batch_raw_tip = ZTX("Convert camera RAW files using libraw");                                            //  16.07
    cchar * batch_rawtherapee_tip = ZTX("Convert camera RAW files using Raw Therapee");
    cchar * scriptfiles_tip = ZTX("Build and run edit script files");
    cchar * burn_tip = ZTX("Burn selected image files to DVD/BlueRay disc");
@@ -423,12 +426,11 @@ void build_widgets()
    MENUENT(mFile,    ZTX("Newest Images"), 0,               newfiles_tip,           m_newfiles, 0 );
    MENUENT(mFile,    ZTX("Open Image File"), 0,             open_tip,               m_open, 0 );
    MENUENT(mFile,    ZTX("Open Previous File"), 0,          prevfiles_tip,          m_previous, 0 );
-   MENUENT(mFile,    ZTX("Open RAW (ufraw)"), 0,            ufraw_tip,              m_ufraw, 0 );
    MENUENT(mFile,    ZTX("Open RAW (Raw Therapee)"), 0,     rawtherapee_tip,        m_rawtherapee, 0 );
    MENUENT(mFile,    ZTX("New Blank Image"), 0,             create_tip,             m_create, 0 );
    MENUENT(mFile,    ZTX("Rename Image File"), 0,           rename_tip,             m_rename, 0 );
-   MENUENT(mFile,    ZTX("Trash Image File"), 0,            trash_tip,              m_trash, 0 );
-   MENUENT(mFile,    ZTX("Delete Image File"), 0,           delete_tip,             m_delete, 0 );
+   MENUENT(mFile,    ZTX("Copy/Move to Location"), 0,       copy_move_tip,          m_copy_move, 0 );
+   MENUENT(mFile,    ZTX("Delete/Trash Image File"), 0,     deltrash_tip,           m_delete_trash, 0 );
    MENUENT(mFile,    ZTX("Print Image"), 0,                 print_tip,              m_print, 0 );
    MENUENT(mFile,    ZTX("Print Calibrated Image"), 0,      print_calibrated_tip,   m_print_calibrated, 0 );
    MENUENT(mFile,    ZTX("Set Desktop Wallpaper"), 0,       setdesktop_tip,         m_setdesktop, 0 );
@@ -445,20 +447,22 @@ void build_widgets()
    MENUENT(mMeta,    ZTX("Batch Rename Tags"), 0,           batch_rename_tags_tip,        m_batch_rename_tags, 0 );
    MENUENT(mMeta,    ZTX("Batch Add/Change Metadata"), 0,   batch_change_metadata_tip,    m_batch_change_metadata, 0 );
    MENUENT(mMeta,    ZTX("Batch Report Metadata"), 0,       batch_report_metadata_tip,    m_batch_report_metadata, 0 );
-   MENUENT(mMeta,    ZTX("Edit Geotags"), 0,                edit_geotags_tip,             m_edit_geotags, 0 );
    MENUENT(mMeta,    ZTX("Batch Add Geotags"), 0,           batch_geotags_tip,            m_batch_geotags, 0 );
-   MENUENT(mMeta,    ZTX("Images by Geotag"), 0,            geotag_groups_tip,            m_geotag_groups, 0 );
    MENUENT(mMeta,    ZTX("Search Images"), 0,               search_images_tip,            m_search_images, 0 );
+   MENUENT(mMeta,    ZTX("Image Locations/Dates"), 0,       locations_tip,                m_locations, 0 );
+   MENUENT(mMeta,    ZTX("Image Timeline"), 0,              timeline_tip,                 m_timeline, 0 );
 
    mArea = create_popmenu();
    MENUENT(mArea,    ZTX("Select"), 0,             select_tip,                m_select, 0 );
+   MENUENT(mArea,    ZTX("Find Gap"), 0,           select_find_gap_tip,       m_select_find_gap, 0 );
+   MENUENT(mArea,    ZTX("Select Hairy"), 0,       select_hairy_tip,          m_select_hairy, 0);
    MENUENT(mArea,    ZTX("Show"), 0,               select_show_tip,           m_select_show, 0 );
    MENUENT(mArea,    ZTX("Hide"), 0,               select_hide_tip,           m_select_hide, 0 );
    MENUENT(mArea,    ZTX("Enable"), 0,             select_enable_tip,         m_select_enable, 0 );
    MENUENT(mArea,    ZTX("Disable"), 0,            select_disable_tip,        m_select_disable, 0 );
    MENUENT(mArea,    ZTX("Invert"), 0,             select_invert_tip,         m_select_invert, 0 );
    MENUENT(mArea,    ZTX("Unselect"), 0,           select_unselect_tip,       m_select_unselect, 0 );
-   MENUENT(mArea,    ZTX("Copy Area"), 0,          select_copy_tip,           m_select_copy, 0 );
+   MENUENT(mArea,    ZTX("Copy Area"), 0,          select_copy_tip,           m_select_save, 0 );
    MENUENT(mArea,    ZTX("Paste Area"), 0,         select_paste_tip,          m_select_paste, 0 );
    MENUENT(mArea,    ZTX("Open Area File"), 0,     select_open_tip,           m_select_open, 0 );
    MENUENT(mArea,    ZTX("Save Area File"), 0,     select_save_tip,           m_select_save, 0 );
@@ -469,7 +473,7 @@ void build_widgets()
    MENUENT(mEdit,    ZTX("Voodoo 1"), 0,                 voodoo1_tip,               m_voodoo1, 0 );
    MENUENT(mEdit,    ZTX("Voodoo 2"), 0,                 voodoo2_tip,               m_voodoo2, 0);
    MENUENT(mEdit,    ZTX("Retouch Combo"), 0,            combo_tip,                 m_combo, 0 );
-   MENUENT(mEdit,    ZTX("Brightness Dist."), 0,         britedist_tip,             m_britedist, 0 );
+   MENUENT(mEdit,    ZTX("Edit Brightness"), 0,          britedist_tip,             m_britedist, 0 );
    MENUENT(mEdit,    ZTX("Zonal Flatten"), 0,            zonal_flatten_tip,         m_zonal_flatten, 0 );
    MENUENT(mEdit,    ZTX("Tone Mapping"), 0,             tonemap_tip,               m_tonemap, 0 );
    MENUENT(mEdit,    ZTX("Resize"), 0,                   resize_tip,                m_resize, 0 );
@@ -494,8 +498,8 @@ void build_widgets()
    MENUENT(mRep,     ZTX("Color Saturation"), 0,      color_sat_tip,          m_colorsat, 0 );
    MENUENT(mRep,     ZTX("Adjust RGB/CMY"), 0,        adjust_RGB_tip,         m_adjust_RGB, 0 );
    MENUENT(mRep,     ZTX("Adjust HSL"), 0,            adjust_HSL_tip,         m_adjust_HSL, 0 );
-   MENUENT(mRep,     ZTX("Brightness Ramp"), 0,       brightramp_tip,         m_brightramp, 0 );
-   MENUENT(mRep,     ZTX("Color Ramp"), 0,            color_ramp_tip,         m_color_ramp, 0 );
+   MENUENT(mRep,     ZTX("Ramp Brightness"), 0,       ramp_brightness_tip,    m_ramp_brightness, 0 );
+   MENUENT(mRep,     ZTX("Ramp Color"), 0,            ramp_color_tip,         m_ramp_color, 0 );
    MENUENT(mRep,     ZTX("Match Colors"), 0,          match_color_tip,        m_match_color, 0 );
    MENUENT(mRep,     ZTX("Color Profile"), 0,         color_profile_tip,      m_color_profile, 0 );
    MENUENT(mRep,     ZTX("Remove Dust"), 0,           remove_dust_tip,        m_remove_dust, 0 );
@@ -548,7 +552,7 @@ void build_widgets()
    MENUENT(mTools,   ZTX("Index Image Files"), 0,           index_tip,                 m_index, 0 );
    MENUENT(mTools,   ZTX("User Options"), 0,                options_tip,               m_options, 0 );
    MENUENT(mTools,   ZTX("Keyboard Shortcuts"), 0,          KBshortcuts_tip,           m_KBshortcuts, 0 );
-   MENUENT(mTools,   ZTX("Show Brightness Dist."), 0,       show_brdist_tip,           m_show_brdist, 0 );
+   MENUENT(mTools,   ZTX("Brightness Graph"), 0,            show_brdist_tip,           m_show_brdist, 0 );
    MENUENT(mTools,   ZTX("Grid Lines"), 0,                  gridlines_tip,             m_gridlines, 0 );
    MENUENT(mTools,   ZTX("Line Color"), 0,                  line_color_tip,            m_line_color, 0 );
    MENUENT(mTools,   ZTX("Show RGB"), 0,                    show_RGB_tip,              m_show_RGB, 0 );
@@ -566,8 +570,8 @@ void build_widgets()
    MENUENT(mBatch,   ZTX("Batch Convert"), 0,               batch_convert_tip,         m_batch_convert, 0 );
    MENUENT(mBatch,   ZTX("Batch Upright"), 0,               batch_upright_tip,         m_batch_upright, 0 );
    MENUENT(mBatch,   ZTX("Batch Delete/Trash"), 0,          batch_deltrash_tip,        m_batch_deltrash, 0 );
-   MENUENT(mBatch,   ZTX("Batch RAW (DCraw)"), 0,           batch_dcraw_tip,           m_batch_dcraw, 0 );
-   MENUENT(mBatch,   ZTX("Batch RAW (Raw Therapee)"), 0,    batch_rawtherapee_tip,     m_batch_rawtherapee, 0 );
+   MENUENT(mBatch,   ZTX("Batch RAW"), 0,                   batch_raw_tip,             m_batch_raw, 0 );            //  16.07
+   MENUENT(mBatch,   ZTX("Batch Raw Therapee"), 0,          batch_rawtherapee_tip,     m_batch_rawtherapee, 0 );    //  16.07
    MENUENT(mBatch,   ZTX("Script Files"), 0,                scriptfiles_tip,           m_scriptfiles, 0 );
    MENUENT(mBatch,   ZTX("Burn Images to DVD/BlueRay"), 0,  burn_tip,                  m_burn, 0 );
    MENUENT(mBatch,   ZTX("Find Duplicate Images"), 0,       duplicates_tip,            m_duplicates, 0 );
@@ -578,7 +582,8 @@ void build_widgets()
    MENUENT(mBatch,   ZTX("Batch Add/Change Metadata"), 0,   batch_change_metadata_tip,    m_batch_change_metadata, 0 );
    MENUENT(mBatch,   ZTX("Batch Report Metadata"), 0,       batch_report_metadata_tip,    m_batch_report_metadata, 0 );
    MENUENT(mBatch,   ZTX("Batch Add Geotags"), 0,           batch_geotags_tip,            m_batch_geotags, 0 );
-   MENUENT(mBatch,   ZTX("Images by Geotag"),  0,           geotag_groups_tip,            m_geotag_groups, 0 );
+   MENUENT(mBatch,   ZTX("Image Locations/Dates"),  0,      locations_tip,                m_locations, 0 );
+   MENUENT(mBatch,   ZTX("Image Timeline"), 0,              timeline_tip,                 m_timeline, 0 );
    MENUENT(mBatch,   ZTX("Search Images"),     0,           search_images_tip,            m_search_images, 0 );
 
    mAlbums = create_popmenu();
@@ -601,7 +606,7 @@ void build_widgets()
 
    //  F view menu (buttons) 
 
-   MENUENT(0,  ZTX("Image"),        "viewF-check.png",   imagefile_tip,       m_viewmode, "F" );
+   MENUENT(0,  Bimage,              "viewF-check.png",   imagefile_tip,       m_viewmode, "F" );
    MENUENT(0,  ZTX("Gallery"),      "viewG.png",         gallery_tip,         m_viewmode, "G" );
    MENUENT(0,  ZTX("World Maps"),   "viewW.png",         worldmaps_tip,       m_viewmode, "W" );
    MENUENT(0,  ZTX("OSM Maps"),     "viewM.png",         OSMmaps_tip,         m_viewmode, "M" );               //  OSM  16.05
@@ -625,7 +630,7 @@ void build_widgets()
 
    //  G view menu (buttons)
 
-   MENUENT(0,  ZTX("Image"),        "viewF.png",         imagefile_tip,          m_viewmode, "F" );
+   MENUENT(0,  Bimage,              "viewF.png",         imagefile_tip,          m_viewmode, "F" );
    MENUENT(0,  ZTX("Gallery"),      "viewG-check.png",   gallery_tip,            m_viewmode, "G" );
    MENUENT(0,  ZTX("World Maps"),   "viewW.png",         worldmaps_tip,          m_viewmode, "W" );
    MENUENT(0,  ZTX("OSM Maps"),     "viewM.png",         OSMmaps_tip,            m_viewmode, "M" );            //  OSM  16.05
@@ -649,29 +654,31 @@ void build_widgets()
 
    //  W view menu (buttons)
 
-   MENUENT(0,  ZTX("Image"),              "viewF.png",            imagefile_tip,       m_viewmode, "F" );
-   MENUENT(0,  ZTX("Gallery"),            "viewG.png",            gallery_tip,         m_viewmode, "G" );
-   MENUENT(0,  ZTX("World Maps"),         "viewW-check.png",      worldmaps_tip,       m_viewmode, "W" );
-   MENUENT(0,  ZTX("OSM Maps"),           "viewM.png",            OSMmaps_tip,         m_viewmode, "M" );      //  OSM  16.05
-   MENUENT(0,  0,                         "separator.png",        0,                   0,           0  );
-   MENUENT(0,  ZTX("Choose Map"),         "choosemap.png",        load_geomap_tip,     m_load_geomap, 0 );
-   MENUENT(0,  ZTX("Search Range"),       "setmaprange.png",      mapsearch_tip,       m_mapsearch_range, 0 );
-   MENUENT(0,  ZTX("Images by Geotag"),   "search.png",           geotag_groups_tip,   m_geotag_groups, 0 );
-   MENUENT(0,  ZTX("Search Images"),      "search.png",           search_images_tip,   m_search_images, 0 );
+   MENUENT(0,  Bimage,                          "viewF.png",            imagefile_tip,       m_viewmode, "F" );
+   MENUENT(0,  ZTX("Gallery"),                  "viewG.png",            gallery_tip,         m_viewmode, "G" );
+   MENUENT(0,  ZTX("World Maps"),               "viewW-check.png",      worldmaps_tip,       m_viewmode, "W" );
+   MENUENT(0,  ZTX("OSM Maps"),                 "viewM.png",            OSMmaps_tip,         m_viewmode, "M" );      //  OSM  16.05
+   MENUENT(0,  0,                               "separator.png",        0,                   0,           0  );
+   MENUENT(0,  ZTX("Choose Map"),               "choosemap.png",        load_geomap_tip,     m_load_geomap, 0 );
+   MENUENT(0,  ZTX("Search Range"),             "setmaprange.png",      mapsearch_tip,       m_mapsearch_range, 0 );
+   MENUENT(0,  ZTX("Image Locations/Dates"),    "search.png",           locations_tip,       m_locations, 0 );
+   MENUENT(0,  ZTX("Image Timeline"),           "search.png",           timeline_tip,        m_timeline, 0 );
+   MENUENT(0,  ZTX("Search Images"),            "search.png",           search_images_tip,   m_search_images, 0 );
 
-   NWmenu = Nmenus;
+   NWmenu = Nmenus;                                                              //  end of W view menus
 
    //  M view menu (buttons)                                                     //  OSM                                16.05
 
-   MENUENT(0,  ZTX("Image"),              "viewF.png",            imagefile_tip,       m_viewmode, "F" );
-   MENUENT(0,  ZTX("Gallery"),            "viewG.png",            gallery_tip,         m_viewmode, "G" );
-   MENUENT(0,  ZTX("World Maps"),         "viewW.png",            worldmaps_tip,       m_viewmode, "W" );
-   MENUENT(0,  ZTX("OSM Maps"),           "viewM-check.png",      OSMmaps_tip,         m_viewmode, "M" );
-   MENUENT(0,  0,                         "separator.png",        0,                   0,           0  );
-   MENUENT(0,  ZTX("Images by Geotag"),   "search.png",           geotag_groups_tip,   m_geotag_groups, 0 );
-   MENUENT(0,  ZTX("Search Images"),      "search.png",           search_images_tip,   m_search_images, 0 );
+   MENUENT(0,  Bimage,                          "viewF.png",            imagefile_tip,       m_viewmode, "F" );
+   MENUENT(0,  ZTX("Gallery"),                  "viewG.png",            gallery_tip,         m_viewmode, "G" );
+   MENUENT(0,  ZTX("World Maps"),               "viewW.png",            worldmaps_tip,       m_viewmode, "W" );
+   MENUENT(0,  ZTX("OSM Maps"),                 "viewM-check.png",      OSMmaps_tip,         m_viewmode, "M" );
+   MENUENT(0,  0,                               "separator.png",        0,                   0,           0  );
+   MENUENT(0,  ZTX("Image Locations/Dates"),    "search.png",           locations_tip,       m_locations, 0 );
+   MENUENT(0,  ZTX("Image Timeline"),           "search.png",           timeline_tip,        m_timeline, 0 );
+   MENUENT(0,  ZTX("Search Images"),            "search.png",           search_images_tip,   m_search_images, 0 );
 
-   NMmenu = Nmenus;
+   NMmenu = Nmenus;                                                              //  end of M view menus
 
    //  dummy menus only for KB shortcuts
 
@@ -722,75 +729,71 @@ void build_widgets()
    //  right-click popup menus --------------------------------------------
 
    cchar    *menupopimage = ZTX("Popup Image");
-   cchar    *menumetadata1 = ZTX("View Metadata");
-   cchar    *menumetadata2 = ZTX("Edit Metadata");
-   cchar    *menumetadata3 = ZTX("Edit Geotags");
+   cchar    *menumeta1 = ZTX("View Metadata");
+   cchar    *menumeta2 = ZTX("Edit Metadata");
+   cchar    *menumeta3 = ZTX("Edit Any Metadata");
    cchar    *menurename = ZTX("Rename");
-   cchar    *menucopytoloc = ZTX("Copy to Location");
-   cchar    *menumovetoloc = ZTX("Move to Location");
+   cchar    *menucopymove = ZTX("Copy/Move to Location");
    cchar    *menucopytoclip = ZTX("Copy to Clipboard");
    cchar    *menuremovefromalbum = ZTX("Remove from Album");
    cchar    *menucuttocache = ZTX("Cut to Image Cache");
    cchar    *menucopytocache = ZTX("Copy to Image Cache");
    cchar    *menupastecachehere = ZTX("Paste Image Cache Here (clear)");
    cchar    *menupastecachekeep = ZTX("Paste Image Cache Here (keep)");
-   cchar    *menupastecurrfile = ZTX("Paste Current Image File Here");
    cchar    *menutrimrotate = ZTX("Trim/Rotate");
    cchar    *menuresize = ZTX("Resize");
    cchar    *menuupright = ZTX("Upright");
-   cchar    *menuvoodoo = ZTX("Voodoo Enhance");
+   cchar    *menuvoodoo1 = "Voodoo 1";
+   cchar    *menuvoodoo2 = "Voodoo 2";
    cchar    *menucombo = ZTX("Retouch Combo");
-   cchar    *menubrightdist = ZTX("Brightness Dist.");
+   cchar    *menubrightdist = ZTX("Edit Brightness");
    cchar    *menuzonalflatten = ZTX("Zonal Flatten");
    cchar    *menutonemap = ZTX("Tone Mapping");
    cchar    *menuselect = ZTX("Select Area");
-   cchar    *menuopenraw1 = ZTX("Open RAW file (ufraw)");
-   cchar    *menuopenraw2 = ZTX("Open RAW file (Raw Therapee)");
-   cchar    *menutrash = ZTX("Trash");
-   cchar    *menudelete = Bdelete;
+   cchar    *menuopenraw = ZTX("Open RAW file (Raw Therapee)");
+   cchar    *menuOSMzoom = ZTX("Show on OSM Map");
+   cchar    *menudeltrash = ZTX("Delete/Trash ...");
 
    popmenu_main = create_popmenu();                                              //  main window image
-   add_popmenu_item(popmenu_main,menumetadata1,popup_menufunc,"view metadata");
-   add_popmenu_item(popmenu_main,menumetadata2,popup_menufunc,"edit metadata");
-   add_popmenu_item(popmenu_main,menumetadata3,popup_menufunc,"edit geotags");
+   add_popmenu_item(popmenu_main,menumeta1,popup_menufunc,"view metadata");
+   add_popmenu_item(popmenu_main,menumeta2,popup_menufunc,"edit metadata");
+   add_popmenu_item(popmenu_main,menumeta3,popup_menufunc,"edit any metadata");
    add_popmenu_item(popmenu_main,menurename,popup_menufunc,"rename");
-   add_popmenu_item(popmenu_main,menucopytoloc,popup_menufunc,"copytoloc");
-   add_popmenu_item(popmenu_main,menumovetoloc,popup_menufunc,"movetoloc");
+   add_popmenu_item(popmenu_main,menucopymove,popup_menufunc,"copymove");
    add_popmenu_item(popmenu_main,menucopytocache,popup_menufunc,"copytocache");
    add_popmenu_item(popmenu_main,menucopytoclip,popup_menufunc,"copytoclip");
    add_popmenu_item(popmenu_main,menuupright,popup_menufunc,"upright");
    add_popmenu_item(popmenu_main,menutrimrotate,popup_menufunc,"trim/rotate");
    add_popmenu_item(popmenu_main,menuresize,popup_menufunc,"resize");
-   add_popmenu_item(popmenu_main,menuvoodoo,popup_menufunc,"voodoo");
+   add_popmenu_item(popmenu_main,menuvoodoo1,popup_menufunc,"voodoo1");
+   add_popmenu_item(popmenu_main,menuvoodoo2,popup_menufunc,"voodoo2");
    add_popmenu_item(popmenu_main,menucombo,popup_menufunc,"combo");
-   add_popmenu_item(popmenu_main,menubrightdist,popup_menufunc,"brightness dist");
+   add_popmenu_item(popmenu_main,menubrightdist,popup_menufunc,"edit brightness");
    add_popmenu_item(popmenu_main,menuzonalflatten,popup_menufunc,"zonal flatten");
    add_popmenu_item(popmenu_main,menutonemap,popup_menufunc,"tonemap");
    add_popmenu_item(popmenu_main,menuselect,popup_menufunc,"select");
-   add_popmenu_item(popmenu_main,menutrash,popup_menufunc,"trash");
-   add_popmenu_item(popmenu_main,menudelete,popup_menufunc,"delete");
+   add_popmenu_item(popmenu_main,menuOSMzoom,popup_menufunc,"OSM_zoomin");
+   add_popmenu_item(popmenu_main,menudeltrash,popup_menufunc,"delete/trash");
 
    popmenu_thumb = create_popmenu();                                             //  gallery thumbnail
    add_popmenu_item(popmenu_thumb,menupopimage,popup_menufunc,"popimage");
-   add_popmenu_item(popmenu_thumb,menumetadata1,popup_menufunc,"view metadata");
+   add_popmenu_item(popmenu_thumb,menumeta1,popup_menufunc,"view metadata");
+   add_popmenu_item(popmenu_thumb,menumeta2,popup_menufunc,"edit metadata");
+   add_popmenu_item(popmenu_thumb,menumeta3,popup_menufunc,"edit any metadata");
    add_popmenu_item(popmenu_thumb,menurename,popup_menufunc,"rename");
-   add_popmenu_item(popmenu_thumb,menuupright,popup_menufunc,"upright thumb");
-   add_popmenu_item(popmenu_thumb,menucopytoloc,popup_menufunc,"copytoloc");
-   add_popmenu_item(popmenu_thumb,menumovetoloc,popup_menufunc,"movetoloc");
+   add_popmenu_item(popmenu_thumb,menucopymove,popup_menufunc,"copymove");
    add_popmenu_item(popmenu_thumb,menucopytocache,popup_menufunc,"copytocache");
    add_popmenu_item(popmenu_thumb,menucopytoclip,popup_menufunc,"copytoclip");
-   add_popmenu_item(popmenu_thumb,menutrash,popup_menufunc,"trash");
-   add_popmenu_item(popmenu_thumb,menudelete,popup_menufunc,"delete");
+   add_popmenu_item(popmenu_thumb,menuupright,popup_menufunc,"upright");
+   add_popmenu_item(popmenu_thumb,menuOSMzoom,popup_menufunc,"OSM_zoomin");
+   add_popmenu_item(popmenu_thumb,menudeltrash,popup_menufunc,"delete/trash");
 
    popmenu_raw = create_popmenu();                                               //  gallery thumbnail, RAW file
-   add_popmenu_item(popmenu_raw,menuopenraw1,m_ufraw,0);
-   add_popmenu_item(popmenu_raw,menuopenraw2,m_rawtherapee,0);
-   add_popmenu_item(popmenu_raw,menumetadata1,popup_menufunc,"view metadata");
+   add_popmenu_item(popmenu_raw,menuopenraw,m_rawtherapee,0);
+   add_popmenu_item(popmenu_raw,menumeta1,popup_menufunc,"view metadata");
    add_popmenu_item(popmenu_raw,menurename,popup_menufunc,"rename");
-   add_popmenu_item(popmenu_raw,menucopytoloc,popup_menufunc,"copytoloc");
-   add_popmenu_item(popmenu_raw,menumovetoloc,popup_menufunc,"movetoloc");
-   add_popmenu_item(popmenu_raw,menutrash,popup_menufunc,"trash");
-   add_popmenu_item(popmenu_raw,menudelete,popup_menufunc,"delete");
+   add_popmenu_item(popmenu_raw,menucopymove,popup_menufunc,"copymove");
+   add_popmenu_item(popmenu_raw,menudeltrash,popup_menufunc,"delete/trash");
 
    popmenu_album = create_popmenu();                                             //  album gallery thumbnail
    add_popmenu_item(popmenu_album,menucopytocache,popup_menufunc,"copytocache");
@@ -798,10 +801,95 @@ void build_widgets()
    add_popmenu_item(popmenu_album,menucopytoclip,popup_menufunc,"copytoclip");
    add_popmenu_item(popmenu_album,menupastecachekeep,popup_menufunc,"pastecachekeep");
    add_popmenu_item(popmenu_album,menupastecachehere,popup_menufunc,"pastecachehere");
-   add_popmenu_item(popmenu_album,menupastecurrfile,popup_menufunc,"pastecurrfile");
    add_popmenu_item(popmenu_album,menuremovefromalbum,popup_menufunc,"removefromalbum");
    add_popmenu_item(popmenu_album,menupopimage,popup_menufunc,"popimage");
-   add_popmenu_item(popmenu_album,menumetadata1,popup_menufunc,"view metadata");
+   add_popmenu_item(popmenu_album,menumeta1,popup_menufunc,"view metadata");
+
+   return;
+}
+
+
+//  right-click popup menu function
+
+void popup_menufunc(GtkWidget *, cchar *menu)
+{
+   if (strmatch(menu,"popimage")) popimage();                                    //  funcs for main and gallery windows
+   if (strmatch(menu,"view metadata")) meta_view(1);
+   if (strmatch(menu,"edit metadata")) m_edit_metadata(0,0);
+   if (strmatch(menu,"edit any metadata")) m_meta_edit_any(0,0);                 //  16.06
+   if (strmatch(menu,"rename")) m_rename(0,0);                                   //  these use clicked_file if defined,
+   if (strmatch(menu,"upright")) m_upright(0,0);                                 //    else they use curr_file.
+   if (strmatch(menu,"copymove")) m_copy_move(0,0);                              //  16.06
+   if (strmatch(menu,"delete/trash")) m_delete_trash(0,0);                       //  16.06
+   if (strmatch(menu,"OSM_zoomin")) m_OSM_zoomin(0,0);                           //  16.06
+   if (strmatch(menu,"copytoclip")) m_copyto_clip(0,0);
+   if (strmatch(menu,"copytocache")) m_copyto_cache(0,0);
+
+   if (strmatch(menu,"removefromalbum")) m_album_removefile(0,0);                //  funcs for album gallery
+   if (strmatch(menu,"cuttocache")) m_album_cutfile(0,0);                        //  depend on clicked_file being defined
+   if (strmatch(menu,"pastecachehere")) m_album_pastecache(0,"clear");
+   if (strmatch(menu,"pastecachekeep")) m_album_pastecache(0,"keep");
+
+   if (strmatch(menu,"trim/rotate")) m_trimrotate(0,0);                          //  functions using curr_file only
+   if (strmatch(menu,"resize")) m_resize(0,0);                                   //  (not used for gallery/thumbnail click)
+   if (strmatch(menu,"voodoo1")) m_voodoo1(0,0);
+   if (strmatch(menu,"voodoo2")) m_voodoo2(0,0);
+   if (strmatch(menu,"combo")) m_combo(0,0);
+   if (strmatch(menu,"edit brightness")) m_britedist(0,0);
+   if (strmatch(menu,"zonal flatten")) m_zonal_flatten(0,0);
+   if (strmatch(menu,"tonemap")) m_tonemap(0,0);
+   if (strmatch(menu,"select")) m_select(0,0);
+
+   return;
+}
+
+
+//  main window mouse right-click popup menu
+
+void image_Rclick_popup()
+{
+   if (! curr_file) return;
+   popup_menu(Mwin,popmenu_main);
+   return;
+}
+
+
+//  gallery thumbnail mouse left-click function
+//  open the clicked file in view mode F
+
+void gallery_Lclick_func(int Nth)
+{
+   char     *file;
+
+   if (checkpend("busy block mods")) return;                                     //  bugfix                             16.05
+   file = gallery(0,"find",Nth);
+   if (! file) return;
+   f_open(file,Nth,0,1);                                                         //  clicked file >> current file
+   zfree(file);
+   m_viewmode(0,"F");
+   return;
+}
+
+
+//  gallery thumbnail mouse right-click popup menu
+
+void gallery_Rclick_popup(int Nth)
+{
+   FTYPE    ftype;
+
+   clicked_posn = Nth;                                                           //  clicked gallery position (0 base)
+   clicked_file = gallery(0,"find",Nth);                                         //  clicked_file is subject for zfree()
+   if (! clicked_file) return;
+   ftype = image_file_type(clicked_file);
+
+   if (navi::gallerytype == ALBUM)                                               //  gallery type is album
+      popup_menu(Mwin,popmenu_album);
+
+   else if (ftype == IMAGE)                                                      //  clicked thumbnail is an image file
+      popup_menu(Mwin,popmenu_thumb);
+
+   else if (ftype == RAW)                                                        //  clicked thumbnail is a RAW file
+      popup_menu(Mwin,popmenu_raw);
 
    return;
 }
@@ -831,6 +919,11 @@ void m_viewmode(GtkWidget *, cchar *fgwm)
       Cstate = &Fstate;                                                          //  set drawing area
       Cdrawin = Fdrawin;
       gdkwin = gtk_widget_get_window(Fdrawin);                                   //  GDK window
+
+      if (zddeltrash) m_delete_trash(0,0);                                       //  reset target file for funcs in     16.06
+      if (zdcopymove) m_copy_move(0,0);                                          //    gallery thumbnail popup menus
+      if (zdexifview) meta_view(0);
+      if (zdrename) m_rename(0,0);
    }
 
    if (*fgwm == 'G')                                                             //  set G view mode for thumbnail gallery
@@ -900,93 +993,7 @@ void m_viewmode(GtkWidget *, cchar *fgwm)
 }
 
 
-//  right-click popup menu function
-
-void popup_menufunc(GtkWidget *, cchar *menu)
-{
-   if (strmatch(menu,"popimage")) popimage();                                    //  funcs for main and gallery windows
-   if (strmatch(menu,"view metadata")) meta_view(1);
-   if (strmatch(menu,"edit metadata")) m_edit_metadata(0,0);
-   if (strmatch(menu,"edit geotags")) m_edit_geotags(0,0);
-   if (strmatch(menu,"rename")) m_rename(0,0);                                   //  these funcs use clicked_file if defined,
-   if (strmatch(menu,"upright thumb")) m_upright(0,0);                           //    else they use curr_file.
-   if (strmatch(menu,"copytoloc")) m_copytoloc(0,0);                             //  set clicked_file to null after use.
-   if (strmatch(menu,"movetoloc")) m_movetoloc(0,0);
-   if (strmatch(menu,"delete")) m_delete(0,0);
-   if (strmatch(menu,"trash")) m_trash(0,0);
-   if (strmatch(menu,"copytoclip")) m_copyto_clip(0,0);
-   if (strmatch(menu,"copytocache")) m_copyto_cache(0,0);
-
-   if (strmatch(menu,"removefromalbum")) album_remove(0,0);                      //  funcs for album gallery
-   if (strmatch(menu,"cuttocache")) album_cutfile(0,0);                          //  depend on clicked_file being defined
-   if (strmatch(menu,"pastecachehere")) album_pastecache(0,"clear");
-   if (strmatch(menu,"pastecachekeep")) album_pastecache(0,"keep");
-   if (strmatch(menu,"pastecurrfile")) album_pastecurrfile(0,0);
-
-   if (strmatch(menu,"trim/rotate")) m_trimrotate(0,0);                          //  functions using curr_file only
-   if (strmatch(menu,"resize")) m_resize(0,0);                                   //  (not used for gallery/thumbnail click)
-   if (strmatch(menu,"upright")) m_upright(0,0);
-   if (strmatch(menu,"voodoo")) m_voodoo1(0,0);
-   if (strmatch(menu,"combo")) m_combo(0,0);
-   if (strmatch(menu,"brightness dist")) m_britedist(0,0);
-   if (strmatch(menu,"zonal flatten")) m_zonal_flatten(0,0);
-   if (strmatch(menu,"tonemap")) m_tonemap(0,0);
-   if (strmatch(menu,"select")) m_select(0,0);
-
-   return;
-}
-
-
-//  main window mouse right-click popup menu
-
-void image_Rclick_popup()
-{
-   if (! curr_file) return;
-   popup_menu(Mwin,popmenu_main);
-   return;
-}
-
-
-//  gallery thumbnail mouse left-click function
-//  open the clicked file in view mode F
-
-void gallery_Lclick_func(int Nth)
-{
-   char     *file;
-
-   if (checkpend("busy block mods")) return;                                     //  bugfix                             16.05
-   file = gallery(0,"find",Nth);
-   if (! file) return;
-   f_open(file,Nth,0,1);                                                         //  clicked file >> current file
-   zfree(file);
-   m_viewmode(0,"F");
-   return;
-}
-
-
-//  gallery thumbnail mouse right-click popup menu
-
-void gallery_Rclick_popup(int Nth)
-{
-   FTYPE    ftype;
-
-   clicked_posn = Nth;                                                           //  clicked gallery position (0 base)
-   clicked_file = gallery(0,"find",Nth);                                         //  clicked_file is subject for zfree()
-   if (! clicked_file) return;
-   ftype = image_file_type(clicked_file);
-
-   if (navi::gallerytype == ALBUM)                                               //  gallery type is album
-      popup_menu(Mwin,popmenu_album);
-
-   else if (ftype == IMAGE)                                                      //  clicked thumbnail is an image file
-      popup_menu(Mwin,popmenu_thumb);
-
-   else if (ftype == RAW)                                                        //  clicked thumbnail is a RAW file
-      popup_menu(Mwin,popmenu_raw);
-
-   return;
-}
-
+/********************************************************************************/
 
 //  favorites menu - popup graphic menu with user's favorites
 
@@ -997,7 +1004,7 @@ void m_favorites(GtkWidget *, cchar *)
 
    F1_help_topic = "favorites_menu";
    snprintf(menuconfigfile,200,"%s/menu-config",favorites_dirk);
-   gmenuz(Mwin,"Favorites",menuconfigfile,favorites_callback);
+   gmenuz(Mwin,ZTX("Favorites"),menuconfigfile,favorites_callback);
    return;
 }
 
