@@ -20,7 +20,7 @@
 
 *********************************************************************************/
 
-//     zfuncs.h   version  v.6.3
+//     zfuncs.h   version  v.6.5
 
 #include <sys/sysinfo.h>
 #include <sys/time.h>
@@ -121,24 +121,22 @@ void resource_unlock(int &resource);
 int  zget_locked(int &param);                                                    //  lock and get multi-thread parameter
 void zput_locked(int &param, int value);                                         //  put and unlock multi-thread parameter
 int  zadd_locked(int &param, int incr);                                          //  increment multi-thread parameter
-
 void start_detached_thread(void * tfunc(void *), void * arg);                    //  start detached thread function
 void synch_threads(int NT = 0);                                                  //  synchronize NT threads
-
-int shell_quiet(cchar *command, ...);                                            //  format/run shell command, return status
-int shell_ack(cchar *command, ...);                                              //   ""  + popup an error message if error
-int shell_asynch(cchar *command, ...);                                           //  start shell command, return immediately
-int shell_asynch_status(int handle);                                             //  get status of asynch shell command
+int  shell_quiet(cchar *command, ...);                                           //  format/run shell command, return status
+int  shell_ack(cchar *command, ...);                                             //   ""  + popup an error message if error
+int  shell_asynch(cchar *command, ...);                                          //  start shell command, return immediately
+int  shell_asynch_status(int handle);                                            //  get status of asynch shell command
 char * command_output(int &contx, cchar *command, ...);                          //  get shell command output
-int command_status(int contx);                                                   //  get exit status of command
-int command_kill(int contx);                                                     //  kill command before completion
-int signalProc(cchar * pname, cchar * signal);                                   //  pause/resume/kill subprocess
-int runroot(cchar *sucomm, cchar *command);                                      //  run command as root via su or sudo
+int  command_status(int contx);                                                  //  get exit status of command
+int  command_kill(int contx);                                                    //  kill command before completion
+int  signalProc(cchar * pname, cchar * signal);                                  //  pause/resume/kill subprocess
+int  runroot(cchar *sucomm, cchar *command);                                     //  run command as root via su or sudo
 char * fgets_trim(char * buff, int maxcc, FILE *, int bf = 0);                   //  fgets + trim trailing \n \r (blanks)
-int samedirk(cchar *file1, cchar *file2);                                        //  returns 1 if files in same directory
-int parsefile(cchar *path, char **dir, char **file, char **ext);                 //  parse a filespec
-int renamez(cchar *file1, cchar *file2);                                         //  rename, also across file systems
-int check_create_dir(char *path);                                                //  check if directory exists, ask to create
+int  samedirk(cchar *file1, cchar *file2);                                       //  returns 1 if files in same directory
+int  parsefile(cchar *path, char **dir, char **file, char **ext);                //  parse a filespec
+int  renamez(cchar *file1, cchar *file2);                                        //  rename, also across file systems
+int  check_create_dir(char *path);                                               //  check if directory exists, ask to create
 
 //  measure CPU time spent in a function or code block within a function
 
@@ -275,7 +273,7 @@ void Qtext_close(Qtext *qtext);
 
 //  application initialization and administration ===============================
 
-int zinitapp(cchar *appname);                                                    //  initz. app directories and files
+int zinitapp(cchar *appname, cchar *userdir = 0);                                //  initz. app directories and files
 
 cchar * get_zprefix();                                                           //  get /usr or /usr/local  ... 
 cchar * get_zuserdir();                                                          //  get /home/user/.appname/
@@ -293,8 +291,6 @@ void showz_logfile();
 void showz_textfile(cchar *type, cchar *file);                                   //  show text file [.gz] in popup window
 void showz_html(cchar *url);                                                     //  show html via preferred browser
 
-void zmake_menu_launcher(cchar *command, cchar *cats, cchar *generic);           //  make desktop menu and launcher
-
 //  translation functions =======================================================
 
 #define ZTXmaxent 2000                                                           //  max. translation strings
@@ -404,10 +400,11 @@ void Vmenu_add(Vmenu *vbm, cchar *name, cchar *icon,
 /********************************************************************************/
 
 //   functions to implement GTK dialogs with less complexity
-//   widget types: dialog, hbox, vbox, hsep, vsep, frame, scrwin, label, entry, edit, radio,
-//                 check, button, togbutt, spin, combo, comboE, hscale, vscale, colorbutt
-
-#define zdmaxwidgets 300                           //  v.5.8
+//   widget types: dialog, hbox, vbox, hsep, vsep, frame, scrwin, label, link, 
+//                 entry, edit, text, radio, check, button, togbutt, spin, 
+//                 combo, comboE, hscale, vscale, imagebutt, colorbutt, icon, image
+                                            
+#define zdmaxwidgets 300
 #define zdmaxbutts 10
 #define zdsentinel 0x97530000
 
@@ -432,6 +429,7 @@ struct zdialog  {
       int         sentinel1, sentinel2;            //  validity sentinels
       int         uniqueID;                        //  unique ID, monotone increasing              
       void        *eventCB;                        //  widget event user callback function
+      int         zrunning;                        //  dialog is running (0,1)
       int         zstat;                           //  dialog status (from completion button)
       int         disabled;                        //  widget signals/events are disabled
       int         saveposn;                        //  save and recall window position each use
@@ -460,6 +458,7 @@ int zdialog_add_widget(zdialog *zd,
 
 int zdialog_valid(zdialog *zd, int errmess = 1);                                 //  return 1/0 if zdialog valid/invalid
 GtkWidget * zdialog_widget(zdialog *zd, cchar *name);                            //  GTK widget from zdialog widget name
+int zdialog_set_image(zdialog *zd, cchar *name, GdkPixbuf *);                    //  set "image" widget from a GDK pixbuf
 int zdialog_add_ttip(zdialog *zd, cchar *wname, cchar *ttip);                    //  add popup tool tip to a widget
 int zdialog_resize(zdialog *zd, int width, int height);                          //  set size > widget sizes
 int zdialog_put_data(zdialog *zd, cchar *name, cchar *data);                     //  put data in widget (entry, spin ...)
@@ -536,8 +535,10 @@ void print_image_file(GtkWidget *parent, cchar *imagefile);
 
 //  drag and drop functions
 
-typedef void drag_drop_func(int x, int y, char *text);                           //  user function, get drag_drop text
-void drag_drop_connect(GtkWidget *window, drag_drop_func);                       //  connect window to user function
+typedef char * drag_drop_source_func();                                          //  user function, set drag-drop text     16.08
+typedef void drag_drop_dest_func(int x, int y, char *text);                      //  user function, get drag-drop text
+void drag_drop_source(GtkWidget *window, drag_drop_source_func);                 //  connect source window to user function
+void drag_drop_dest(GtkWidget *window, drag_drop_dest_func);                     //  connect destination window to user function
 
 //  miscellaneous GDK/GTK functions
 
